@@ -7,7 +7,7 @@ use Mojo::Base -role;
 
 use Scalar::Util 'refaddr';
 
-our $VERSION = "v0.0.2";
+our $VERSION = "v0.0.3";
 
 has max_attempts => 1;
 
@@ -201,7 +201,8 @@ Mojo::UserAgent::Role::Resume - Role for Mojo::UserAgent that provides resuming
         print $tx->res->headers->to_string;
     });
 
-    # The last snippet will save the entire file to downloaded_file.zip, and will print:
+    # The last snippet will save the entire file to downloaded_file.zip regardless of temporary disconnects, and
+    # will print something like this:
     Connection: keep-alive
     Content-Length: 103124119
     Server: nginx
@@ -217,16 +218,16 @@ Mojo::UserAgent::Role::Resume - Role for Mojo::UserAgent that provides resuming
 Mojo::UserAgent::Role::Resume is a role for Mojo::UserAgent that allows the user-agent to
 retry a URL upon failure.
 
-Retries are made after a connection error or after a server error (HTTP error 5xx) occurs.
+Retries are made after a connection error or after a server error (HTTP status 5xx) occurs.
 
 It will intelligently determine whether the server it's downloading from properly supports ranged requests,
 and if it doesn't, then upon failure it will stop asking for a resume and request the complete file again
 from scratch.
 
-It will request the original user-provided URL in its next attempts, not the one that may have resulted from
+It will request the original user-provided request in its next attempts, not the one that may have resulted from
 redirections of the first attempt.
 
-The $tx object returned is the last HTTP transaction that took place.
+The C<$tx> object returned is the last HTTP transaction that took place.
 
 =head1 ATTRIBUTES
 
@@ -238,7 +239,7 @@ L<Mojo::UserAgent::Role::Resume> adds the following attribute to the L<Mojo::Use
     $ua->max_attempts(5);
 
 The number of attempts it will try (at most). What matters for each download is the value this attribute held
-at the time the first attempt took place.
+at the time the first attempt of that download took place.
 
 =head1 TODO
 
@@ -251,7 +252,7 @@ determining whether to retry
 
 =item * Add events
 
-=item * Find the right minimum versions of its dependencies
+=item * Find the right minimum versions for its dependencies
 
 =back
 
